@@ -14,14 +14,17 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from collections import OrderedDict
+import collections
 import fnmatch
 import json
 import logging
 import os
 import sys
+import tokenize
 import traceback
 
+import six
+
 from bandit.core import constants as b_constants
 from bandit.core import extension_loader
 from bandit.core import issue
@@ -31,15 +34,15 @@ from bandit.core import node_visitor as b_node_visitor
 from bandit.core import test_set as b_test_set
 
 
-logger = logging.getLogger(__name__)
+LOG = logging.getLogger(__name__)
 
 
-class BanditManager():
+class BanditManager(object):
 
     scope = []
 
     def __init__(self, config, agg_type, debug=False, verbose=False,
-                 profile={}, ignore_nosec=False):
+                 quiet=False, profile=None, ignore_nosec=False):
         '''Get logger, config, AST handler, and result store ready
 
         :param config: config options object
@@ -47,12 +50,16 @@ class BanditManager():
         :param agg_type: aggregation type
         :param debug: Whether to show debug messages or not
         :param verbose: Whether to show verbose output
+        :param quiet: Whether to only show output in the case of an error
         :param profile_name: Optional name of profile to use (from cmd line)
         :param ignore_nosec: Whether to ignore #nosec or not
         :return:
         '''
         self.debug = debug
         self.verbose = verbose
+        self.quiet = quiet
+        if not profile:
+            profile = {}
         self.ignore_nosec = ignore_nosec
         self.b_conf = config
         self.files_list = []
@@ -69,6 +76,16 @@ class BanditManager():
         self.progress = b_constants.progress_increment
         self.scores = []
 
+    def get_skipped(self):
+        ret = []
+        # "skip" is a tuple of name and reason, decode just the name
+        for skip in self.skipped:
+            if isinstance(skip[0], bytes):
+                ret.append((skip[0].decode('utf-8'), skip[1]))
+            else:
+                ret.append(skip)
+        return ret
+
     def get_issue_list(self,
                        sev_level=b_constants.LOW,
                        conf_level=b_constants.LOW):
@@ -86,7 +103,7 @@ class BanditManager():
             jdata = json.loads(data)
             items = [issue.issue_from_dict(j) for j in jdata["results"]]
         except Exception as e:
-            logger.warning("Failed to load baseline data: %s", e)
+            LOG.warning("Failed to load baseline data: %s", e)
         self.baseline = items
 
     def filter_results(self, sev_filter, conf_filter):
@@ -124,7 +141,7 @@ class BanditManager():
         return len(self.get_issue_list(sev_filter, conf_filter))
 
     def output_results(self, lines, sev_level, conf_level, output_file,
-                       output_format):
+                       output_format, template=None):
         '''Outputs results from the result store
 
         :param lines: How many surrounding lines to show per result
@@ -132,6 +149,9 @@ class BanditManager():
         :param conf_level: Which confidence levels to show (LOW, MEDIUM, HIGH)
         :param output_file: File to store results
         :param output_format: output format plugin name
+        :param template: Output template with non-terminal tags <N>
+                         (default:  {abspath}:{line}:
+                         {test_id}[bandit]: {severity}: {msg})
         :return: -
         '''
         try:
@@ -141,8 +161,12 @@ class BanditManager():
 
             formatter = formatters_mgr[output_format]
             report_func = formatter.plugin
-            report_func(self, fileobj=output_file, sev_level=sev_level,
-                        conf_level=conf_level, lines=lines)
+            if output_format == 'custom':
+                report_func(self, fileobj=output_file, sev_level=sev_level,
+                            conf_level=conf_level, template=template)
+            else:
+                report_func(self, fileobj=output_file, sev_level=sev_level,
+                            conf_level=conf_level, lines=lines)
 
         except Exception as e:
             raise RuntimeError("Unable to output report using '%s' formatter: "
@@ -160,13 +184,16 @@ class BanditManager():
         files_list = set()
         excluded_files = set()
 
-        excluded_path_strings = self.b_conf.get_option('exclude_dirs') or []
+        excluded_path_globs = self.b_conf.get_option('exclude_dirs') or []
         included_globs = self.b_conf.get_option('include') or ['*.py']
 
         # if there are command line provided exclusions add them to the list
         if excluded_paths:
             for path in excluded_paths.split(','):
-                excluded_path_strings.append(path)
+                if os.path.isdir(path):
+                    path = os.path.join(path, '*')
+
+                excluded_path_globs.append(path)
 
         # build list of files we will analyze
         for fname in targets:
@@ -176,20 +203,20 @@ class BanditManager():
                     new_files, newly_excluded = _get_files_from_dir(
                         fname,
                         included_globs=included_globs,
-                        excluded_path_strings=excluded_path_strings
+                        excluded_path_strings=excluded_path_globs
                     )
                     files_list.update(new_files)
                     excluded_files.update(newly_excluded)
                 else:
-                    logger.warning("Skipping directory (%s), use -r flag to "
-                                   "scan contents", fname)
+                    LOG.warning("Skipping directory (%s), use -r flag to "
+                                "scan contents", fname)
 
             else:
                 # if the user explicitly mentions a file on command line,
                 # we'll scan it, regardless of whether it's in the included
                 # file types list
                 if _is_file_included(fname, included_globs,
-                                     excluded_path_strings,
+                                     excluded_path_globs,
                                      enforce_glob=False):
                     files_list.add(fname)
                 else:
@@ -212,7 +239,7 @@ class BanditManager():
         new_files_list = list(self.files_list)
 
         for count, fname in enumerate(self.files_list):
-            logger.debug("working on file : %s", fname)
+            LOG.debug("working on file : %s", fname)
 
             if len(self.files_list) > self.progress:
                 # is it time to update the progress indicator?
@@ -220,48 +247,12 @@ class BanditManager():
                     sys.stderr.write("%s.. " % count)
                     sys.stderr.flush()
             try:
-                with open(fname, 'rb') as fdata:
-                    try:
-                        # parse the current file
-                        data = fdata.read()
-                        lines = data.splitlines()
-                        self.metrics.begin(fname)
-                        self.metrics.count_locs(lines)
-                        if self.ignore_nosec:
-                            nosec_lines = set()
-                        else:
-                            nosec_lines = set(
-                                lineno + 1 for
-                                (lineno, line) in enumerate(lines)
-                                if b'#nosec' in line or b'# nosec' in line)
-                        score = self._execute_ast_visitor(fname, data,
-                                                          nosec_lines)
-                        self.scores.append(score)
-                        self.metrics.count_issues([score, ])
-                    except KeyboardInterrupt as e:
-                        sys.exit(2)
-                    except SyntaxError as e:
-                        self.skipped.append((
-                            fname,
-                            "syntax error while parsing AST from file"
-                        ))
-                        new_files_list.remove(fname)
-                    except Exception as e:
-                        logger.error(
-                            "Exception occurred when executing tests against "
-                            "{0}. Run \"bandit --debug {0}\" to see the full "
-                            "traceback.".format(fname)
-                        )
-                        self.skipped.append(
-                            (fname, 'exception while scanning file')
-                        )
-                        new_files_list.remove(fname)
-                        logger.debug("  Exception string: %s", e)
-                        logger.debug(
-                            "  Exception traceback: %s",
-                            traceback.format_exc()
-                        )
-                        continue
+                if fname == '-':
+                    sys.stdin = os.fdopen(sys.stdin.fileno(), 'rb', 0)
+                    self._parse_file('<stdin>', sys.stdin, new_files_list)
+                else:
+                    with open(fname, 'rb') as fdata:
+                        self._parse_file(fname, fdata, new_files_list)
             except IOError as e:
                 self.skipped.append((fname, e.strerror))
                 new_files_list.remove(fname)
@@ -276,6 +267,46 @@ class BanditManager():
         # do final aggregation of metrics
         self.metrics.aggregate()
 
+    def _parse_file(self, fname, fdata, new_files_list):
+        try:
+            # parse the current file
+            data = fdata.read()
+            lines = data.splitlines()
+            self.metrics.begin(fname)
+            self.metrics.count_locs(lines)
+            if self.ignore_nosec:
+                nosec_lines = set()
+            else:
+                try:
+                    fdata.seek(0)
+                    if six.PY2:
+                        tokens = tokenize.generate_tokens(fdata.readline)
+                    else:
+                        tokens = tokenize.tokenize(fdata.readline)
+                    nosec_lines = set(
+                        lineno for toktype, tokval, (lineno, _), _, _ in tokens
+                        if toktype == tokenize.COMMENT and
+                        '#nosec' in tokval or '# nosec' in tokval)
+                except tokenize.TokenError as e:
+                    nosec_lines = set()
+            score = self._execute_ast_visitor(fname, data, nosec_lines)
+            self.scores.append(score)
+            self.metrics.count_issues([score, ])
+        except KeyboardInterrupt as e:
+            sys.exit(2)
+        except SyntaxError as e:
+            self.skipped.append((fname,
+                                 "syntax error while parsing AST from file"))
+            new_files_list.remove(fname)
+        except Exception as e:
+            LOG.error("Exception occurred when executing tests against "
+                      "%s. Run \"bandit --debug %s\" to see the full "
+                      "traceback.", fname, fname)
+            self.skipped.append((fname, 'exception while scanning file'))
+            new_files_list.remove(fname)
+            LOG.debug("  Exception string: %s", e)
+            LOG.debug("  Exception traceback: %s", traceback.format_exc())
+
     def _execute_ast_visitor(self, fname, data, nosec_lines):
         '''Execute AST parse on each file
 
@@ -294,15 +325,17 @@ class BanditManager():
         return score
 
 
-def _get_files_from_dir(files_dir, included_globs=['*.py'],
+def _get_files_from_dir(files_dir, included_globs=None,
                         excluded_path_strings=None):
+    if not included_globs:
+        included_globs = ['*.py']
     if not excluded_path_strings:
         excluded_path_strings = []
 
     files_list = set()
     excluded_files = set()
 
-    for root, subdirs, files in os.walk(files_dir):
+    for root, _, files in os.walk(files_dir):
         for filename in files:
             path = os.path.join(root, filename)
             if _is_file_included(path, included_globs, excluded_path_strings):
@@ -323,7 +356,8 @@ def _is_file_included(path, included_globs, excluded_path_strings,
 
     :param path: Full path of file to check
     :param parsed_extensions: List of parsed extensions
-    :param excluded_paths: List of paths from which we should not include files
+    :param excluded_paths: List of paths (globbing supported) from which we
+        should not include files
     :param enforce_glob: Can set to false to bypass extension check
     :return: Boolean indicating whether a file should be included
     '''
@@ -332,7 +366,8 @@ def _is_file_included(path, included_globs, excluded_path_strings,
     # if this is matches a glob of files we look at, and it isn't in an
     # excluded path
     if _matches_glob_list(path, included_globs) or not enforce_glob:
-        if not any(x in path for x in excluded_path_strings):
+        if (not _matches_glob_list(path, excluded_path_strings) and
+                not any(x in path for x in excluded_path_strings)):
             return_value = True
 
     return return_value
@@ -371,7 +406,7 @@ def _find_candidate_matches(unmatched_issues, results_list):
     :return: A dictionary with a list of candidates for each issue
     """
 
-    issue_candidates = OrderedDict()
+    issue_candidates = collections.OrderedDict()
 
     for unmatched in unmatched_issues:
         issue_candidates[unmatched] = ([i for i in results_list if
