@@ -21,10 +21,9 @@ import operator
 from bandit.core import constants
 from bandit.core import tester as b_tester
 from bandit.core import utils as b_utils
-from bandit.core.utils import InvalidModulePath
 
 
-logger = logging.getLogger(__name__)
+LOG = logging.getLogger(__name__)
 
 
 class BanditNodeVisitor(object):
@@ -49,11 +48,11 @@ class BanditNodeVisitor(object):
         # in some cases we can't determine a qualified name
         try:
             self.namespace = b_utils.get_module_qualname_from_path(fname)
-        except InvalidModulePath:
-            logger.info('Unable to find qualified name for module: %s',
-                        self.fname)
+        except b_utils.InvalidModulePath:
+            LOG.info('Unable to find qualified name for module: %s',
+                     self.fname)
             self.namespace = ""
-        logger.debug('Module qualified name: %s', self.namespace)
+        LOG.debug('Module qualified name: %s', self.namespace)
         self.metrics = metrics
 
     def visit_ClassDef(self, node):
@@ -162,8 +161,10 @@ class BanditNodeVisitor(object):
         :return: -
         '''
         self.context['str'] = node.s
-        if not isinstance(node.parent, ast.Expr):  # docstring
-            self.context['linerange'] = b_utils.linerange_fix(node.parent)
+        if not isinstance(node._bandit_parent, ast.Expr):  # docstring
+            self.context['linerange'] = b_utils.linerange_fix(
+                node._bandit_parent
+            )
             self.update_scores(self.tester.run_tests(self.context, 'Str'))
 
     def visit_Bytes(self, node):
@@ -175,8 +176,10 @@ class BanditNodeVisitor(object):
         :return: -
         '''
         self.context['bytes'] = node.s
-        if not isinstance(node.parent, ast.Expr):  # docstring
-            self.context['linerange'] = b_utils.linerange_fix(node.parent)
+        if not isinstance(node._bandit_parent, ast.Expr):  # docstring
+            self.context['linerange'] = b_utils.linerange_fix(
+                node._bandit_parent
+            )
             self.update_scores(self.tester.run_tests(self.context, 'Bytes'))
 
     def pre_visit(self, node):
@@ -185,14 +188,14 @@ class BanditNodeVisitor(object):
         self.context['import_aliases'] = self.import_aliases
 
         if self.debug:
-            logger.debug(ast.dump(node))
+            LOG.debug(ast.dump(node))
             self.metaast.add_node(node, '', self.depth)
 
         if hasattr(node, 'lineno'):
             self.context['lineno'] = node.lineno
 
             if node.lineno in self.nosec_lines:
-                logger.debug("skipped, nosec")
+                LOG.debug("skipped, nosec")
                 self.metrics.note_nosec()
                 return False
 
@@ -201,10 +204,10 @@ class BanditNodeVisitor(object):
         self.context['filename'] = self.fname
 
         self.seen += 1
-        logger.debug("entering: %s %s [%s]", hex(id(node)), type(node),
-                     self.depth)
+        LOG.debug("entering: %s %s [%s]", hex(id(node)), type(node),
+                  self.depth)
         self.depth += 1
-        logger.debug(self.context)
+        LOG.debug(self.context)
         return True
 
     def visit(self, node):
@@ -213,14 +216,14 @@ class BanditNodeVisitor(object):
         visitor = getattr(self, method, None)
         if visitor is not None:
             if self.debug:
-                logger.debug("%s called (%s)", method, ast.dump(node))
+                LOG.debug("%s called (%s)", method, ast.dump(node))
             visitor(node)
         else:
             self.update_scores(self.tester.run_tests(self.context, name))
 
     def post_visit(self, node):
         self.depth -= 1
-        logger.debug("%s\texiting : %s", self.depth, hex(id(node)))
+        LOG.debug("%s\texiting : %s", self.depth, hex(id(node)))
 
         # HACK(tkelsey): this is needed to clean up post-recursion stuff that
         # gets setup in the visit methods for these node types.
@@ -235,10 +238,10 @@ class BanditNodeVisitor(object):
                 for idx, item in enumerate(value):
                     if isinstance(item, ast.AST):
                         if idx < max_idx:
-                            setattr(item, 'sibling', value[idx + 1])
+                            setattr(item, '_bandit_sibling', value[idx + 1])
                         else:
-                            setattr(item, 'sibling', None)
-                        setattr(item, 'parent', node)
+                            setattr(item, '_bandit_sibling', None)
+                        setattr(item, '_bandit_parent', node)
 
                         if self.pre_visit(item):
                             self.visit(item)
@@ -246,8 +249,8 @@ class BanditNodeVisitor(object):
                             self.post_visit(item)
 
             elif isinstance(value, ast.AST):
-                setattr(value, 'sibling', None)
-                setattr(value, 'parent', node)
+                setattr(value, '_bandit_sibling', None)
+                setattr(value, '_bandit_parent', node)
 
                 if self.pre_visit(value):
                     self.visit(value)
