@@ -5,12 +5,20 @@ query = "SELECT * FROM foo WHERE id = '%s'" % identifier
 query = "INSERT INTO foo VALUES ('a', 'b', '%s')" % value
 query = "DELETE FROM foo WHERE id = '%s'" % identifier
 query = "UPDATE foo SET value = 'b' WHERE id = '%s'" % identifier
+query = """WITH cte AS (SELECT x FROM foo)
+SELECT x FROM cte WHERE x = '%s'""" % identifier
+# bad alternate forms
+query = "SELECT * FROM foo WHERE id = '" + identifier + "'"
+query = "SELECT * FROM foo WHERE id = '{}'".format(identifier)
 
 # bad
 cur.execute("SELECT * FROM foo WHERE id = '%s'" % identifier)
 cur.execute("INSERT INTO foo VALUES ('a', 'b', '%s')" % value)
 cur.execute("DELETE FROM foo WHERE id = '%s'" % identifier)
 cur.execute("UPDATE foo SET value = 'b' WHERE id = '%s'" % identifier)
+# bad alternate forms
+cur.execute("SELECT * FROM foo WHERE id = '" + identifier + "'")
+cur.execute("SELECT * FROM foo WHERE id = '{}'".format(identifier))
 
 # good
 cur.execute("SELECT * FROM foo WHERE id = '%s'", identifier)
@@ -18,13 +26,6 @@ cur.execute("INSERT INTO foo VALUES ('a', 'b', '%s')", value)
 cur.execute("DELETE FROM foo WHERE id = '%s'", identifier)
 cur.execute("UPDATE foo SET value = 'b' WHERE id = '%s'", identifier)
 
-# bad
-query = "SELECT " + val + " FROM " + val +" WHERE id = " + val
-
-# bad
-cur.execute("SELECT " + val + " FROM " + val +" WHERE id = " + val)
-
-
 # bug: https://bugs.launchpad.net/bandit/+bug/1479625
 def a():
     def b():
