@@ -45,11 +45,11 @@ class ScreenFormatterTests(testtools.TestCase):
                           "{}   Severity: {}   Confidence: {}".
                           format(_indent_val, _issue.severity.capitalize(),
                                  _issue.confidence.capitalize()),
-                          "{}   Location: {}:{}{}".
-                          format(_indent_val, _issue.fname, _issue.lineno,
-                                 screen.COLOR['DEFAULT']),
-                          "{}   More Info: {}".format(
-                              _indent_val, docs_utils.get_url(_issue.test_id))]
+                          "{}   Location: {}:{}".
+                          format(_indent_val, _issue.fname, _issue.lineno),
+                          "{}   More Info: {}{}".format(
+                              _indent_val, docs_utils.get_url(_issue.test_id),
+                              screen.COLOR['DEFAULT'])]
             if _code:
                 return_val.append("{}{}".format(_indent_val, _code))
             return '\n'.join(return_val)
@@ -82,9 +82,9 @@ class ScreenFormatterTests(testtools.TestCase):
 
         get_issue_list.return_value = collections.OrderedDict()
         with mock.patch('bandit.formatters.screen.do_print') as m:
-            tmp_file = open(self.tmp_fname, 'w')
-            screen.report(self.manager, tmp_file, bandit.LOW, bandit.LOW,
-                          lines=5)
+            with open(self.tmp_fname, 'w') as tmp_file:
+                screen.report(self.manager, tmp_file, bandit.LOW, bandit.LOW,
+                              lines=5)
             self.assertIn('No issues identified.',
                           '\n'.join([str(a) for a in m.call_args]))
 
@@ -121,9 +121,9 @@ class ScreenFormatterTests(testtools.TestCase):
         with mock.patch(output_str_fn) as output_str:
             output_str.return_value = 'ISSUE_OUTPUT_TEXT'
 
-            tmp_file = open(self.tmp_fname, 'w')
-            screen.report(self.manager, tmp_file, bandit.LOW, bandit.LOW,
-                          lines=5)
+            with open(self.tmp_fname, 'w') as tmp_file:
+                screen.report(self.manager, tmp_file, bandit.LOW, bandit.LOW,
+                              lines=5)
 
             calls = [mock.call(issue_a, '', lines=5),
                      mock.call(issue_b, '', lines=5)]
@@ -133,9 +133,9 @@ class ScreenFormatterTests(testtools.TestCase):
         # Validate that we're outputting all of the expected fields and the
         # correct values
         with mock.patch('bandit.formatters.screen.do_print') as m:
-            tmp_file = open(self.tmp_fname, 'w')
-            screen.report(self.manager, tmp_file, bandit.LOW, bandit.LOW,
-                          lines=5)
+            with open(self.tmp_fname, 'w') as tmp_file:
+                screen.report(self.manager, tmp_file, bandit.LOW, bandit.LOW,
+                              lines=5)
 
             data = '\n'.join([str(a) for a in m.call_args[0][0]])
 
@@ -195,9 +195,9 @@ class ScreenFormatterTests(testtools.TestCase):
         with mock.patch(output_str_fn) as output_str:
             output_str.return_value = 'ISSUE_OUTPUT_TEXT'
 
-            tmp_file = open(self.tmp_fname, 'w')
-            screen.report(self.manager, tmp_file, bandit.LOW, bandit.LOW,
-                          lines=5)
+            with open(self.tmp_fname, 'w') as tmp_file:
+                screen.report(self.manager, tmp_file, bandit.LOW, bandit.LOW,
+                              lines=5)
 
             calls = [mock.call(issue_a, '', lines=5),
                      mock.call(issue_b, '', show_code=False,
